@@ -15,8 +15,6 @@ versioning_manager = VersioningManager()
 class Versioned(object):
     __versioned__ = {}
 
-    revision = sa.Column(sa.Integer)
-
 
 def make_versioned(
     mapper=sa.orm.mapper,
@@ -29,22 +27,42 @@ def make_versioned(
     sa.event.listen(
         mapper, 'after_configured', manager.configure_versioned_classes
     )
+
+    uow = manager.uow
+
     sa.event.listen(
-        session, 'before_flush', manager.assign_revisions
+        mapper, 'before_delete', uow.track_deletes
     )
     sa.event.listen(
-        session, 'after_flush', manager.create_version_objects
+        mapper, 'before_update', uow.track_updates
     )
     sa.event.listen(
-        session, 'before_commit', manager.create_transaction_log_entry
+        mapper, 'before_insert', uow.track_inserts
     )
+
     sa.event.listen(
-        session, 'before_commit', manager.create_transaction_changes_entries
+        session, 'after_flush', uow.create_version_objects
+    )
+    sa.event.listen(
+        session, 'after_flush', uow.create_transaction_changes_entries
+    )
+
+    sa.event.listen(
+        session, 'before_commit', uow.create_transaction_log_entry
+    )
+    sa.event.listen(
+        session, 'before_commit', uow.before_commit
     )
 
-    # after_insert(mapper, connection, target)
     sa.event.listen(
         sa.engine.Engine,
         'before_cursor_execute',
-        manager.version_association_table_records
+        uow.version_association_table_records
+    )
+
+    sa.event.listen(
+        session, 'after_commit', uow.clear_transaction
+    )
+    sa.event.listen(
+        session, 'after_rollback', uow.clear_transaction
     )
